ZwergETL Basic Components
==========================

Basic components for ZwergETL framework.

This package includes the following components:

1. `CsvReader` - reads csv files
2. `CsvWriter` - writes csv files
3. `Dummy` - consumes data from input port and optionally prints it to stdout. For debugging ETL pipelines.
4. `HashCalc` - calculates md5-hashes on specified set of fields.
5. `Reformat` - performs user-defined calculations on records.
